@@ -26,21 +26,17 @@
 #'            dimnames = list(x_vals, y_vals, z_vals))
 #'
 #' ## "Melt" the array into a dataframe
-#' array_melt(array = g)
+#' supportR::array_melt(array = g)
 #'
 array_melt <- function(array = NULL){
 
   # Squelch visible bindings note
   . <- z <- y_raw <- y <- NULL
 
-  # Error out if `array` is null
-  if(is.null(array) == TRUE)
-    stop("'array' must be provided")
-
-  # Error out if `array` isn't an array
-  if(methods::is(object = array, class2 = "array") != TRUE)
-    stop("'array' must be an array")
-    
+  # Error checks for array
+  if(is.null(array) || methods::is(object = array, class2 = "array") != TRUE)
+    stop("'array' must be provided as an array")
+  
   # Actual parsing of array
   df <- array %>%
     # Flatten array to a list (margin = 3 because each z should be in a separate list element)
