@@ -10,22 +10,18 @@
 #' @examples
 #' \dontrun{
 #' # List contents of the top-level of the `supportR` package repository
-#' github_ls_single(repo = "https://github.com/njlyon0/supportR")
+#' supportR::github_ls_single(repo = "https://github.com/njlyon0/supportR")
 #' }
 #' 
 github_ls_single <- function(repo = NULL, folder = NULL){
   
-  # Error out for missing repo URL
-  if(is.null(repo) == TRUE)
+  # Error checks for repo URL
+  if(is.null(repo) || stringr::str_detect(string = repo, pattern = "github.com"))
     stop("'repo' must be the URL for a GitHub repository (including 'github.com')")
   
   # Break URL into its component parts
   url_bits <- stringr::str_split_1(string = repo, pattern = "/")
   
-  # Error out if "github.com" isn't in the URL
-  if(!"github.com" %in% url_bits)
-    stop("'repo' must be the URL for a GitHub repository (including 'github.com')")
-  
   # Drop unwanted parts of that
   repo_id <- setdiff(x = url_bits, y = c("https:", "", "www.", "github.com"))
   
@@ -45,7 +41,7 @@ github_ls_single <- function(repo = NULL, folder = NULL){
   repo_types <- NULL
   
   # Identify files in that folder
-  for(k in 1:length(repo_contents)){
+  for(k in seq_along(repo_contents)){
     
     # Strip out vector of file/directory names and types
     repo_names <- c(repo_names, repo_contents[[k]]$name)
@@ -61,7 +57,6 @@ github_ls_single <- function(repo = NULL, folder = NULL){
   return(repo_df) }
 
 
-
 #' @title List Objects in a GitHub Repository
 #' 
 #' @description Accepts a GitHub repository URL and identifies all files in the specified folder. If no folder is specified, lists top-level repository contents. Recursive listing of sub-folders is supported by an additional argument. This function only works on repositories (public or private) to which you have access.
@@ -80,13 +75,18 @@ github_ls_single <- function(repo = NULL, folder = NULL){
 #' @examples
 #' \dontrun{
 #' # List complete contents of the `supportR` package repository
-#' github_ls(repo = "https://github.com/njlyon0/supportR", recursive = TRUE, quiet = FALSE)
+#' supportR::github_ls(repo = "https://github.com/njlyon0/supportR", recursive = TRUE, quiet = FALSE)
 #' }
 #' 
 github_ls <- function(repo = NULL, folder = NULL, recursive = TRUE, quiet = FALSE){
   # Squelch visible bindings note
   type <- name <- listed <- NULL
   
+  # Warning for non-logical quiet
+  if(is.logical(quiet) != TRUE){
+    warning("'quiet' must be logical. Defaulting to FALSE")
+    quiet <- FALSE }
+  
   # Message top-level listing (if `quiet` is not TRUE)
   if(quiet != TRUE){ 
     message(ifelse(test = is.null(folder) == TRUE,
@@ -146,11 +146,8 @@ github_ls <- function(repo = NULL, folder = NULL, recursive = TRUE, quiet = FALS
                                           no = listed))
           
         } # Close sublisting conditional
-        
       } # Close `for` loop
-      
     } # Close `while` loop
-    
   } # Close recursive conditional
   
   # Wrangle that output slightly
