@@ -14,7 +14,7 @@
 #' @examples
 #' \dontrun{
 #' # Create a file tree for the `supportR` package GitHub repository
-#' github_tree(repo = "github.com/njlyon0/supportR", exclude = c("man", "docs", ".github"))
+#' supportR::github_tree(repo = "github.com/njlyon0/supportR", exclude = c("man", "docs", ".github"))
 #' }
 #' 
 github_tree <- function(repo = NULL, exclude = NULL, quiet = FALSE){
@@ -41,7 +41,7 @@ github_tree <- function(repo = NULL, exclude = NULL, quiet = FALSE){
                               exclude_num = 0)
     
     # Identify all rows where excluded files are part of the path
-    for(j in 1:length(exclude)){
+    for(j in seq_along(exclude)){
       
       # Identify all contents of folders that are marked for exclusion
       conts_v2 %<>%
