@@ -17,46 +17,41 @@
 #' fish <- data.frame("species" = spp, "count" = ct, "num_col2" = ct2, "third_count" = ct3)
 #'
 #' # Use `num_check()` to return only the entries that would be lost
-#' num_check(data = fish, col = c("count", "num_col2", "third_count"))
+#' supportR::num_check(data = fish, col = c("count", "num_col2", "third_count"))
 #' 
 num_check <- function(data = NULL, col = NULL) {
 
-  # Error out if anything is missing
-  if(is.null(data) == TRUE)
-    stop("Data object name must be provided")
+  # Error checks for data
+  if(is.null(data) || "data.frame" %in% class(data) != TRUE)
+    stop("'data' must be specified as a dataframe-like object")
   
-  # Error out if column(s) is/are missing
-  if(is.null(col) == TRUE)
-    stop("Column name(s) must be provided")
-  
-  # Error out for non-dataframe data
-  if(any(class(data) == "data.frame") != TRUE)
-    stop("Data object must be dataframe-like")
+  # Error checks for 'col' column
+  if(is.null(col) || length(col) < 1)
+    stop("'col' must be provided as at least one character/numeric value")
   
   # Make an empty list to store the malformed dates in
-  bad_list <- base::list()
+  bad_list <- list()
   
   # Make data a dataframe
-  df <- base::as.data.frame(data)
+  df <- as.data.frame(data)
 
   # For each supplied column...
-  for(k in 1:length(col)) {
+  for(k in seq_along(col)) {
     
     # Identify the specific column option
     col_opt <- col[k]
     
     # Remove NA entries
-    not_na <- base::subset(df, !base::is.na(df[, col_opt]))
+    not_na <- subset(df, !is.na(df[, col_opt]))
     
     # Identify rows that would be lost if `as.numeric()` is used
-    bad_df <- base::subset(not_na,
-                           base::is.na(supportR::force_num(x = not_na[, col_opt])))
+    bad_df <- subset(not_na, is.na(supportR::force_num(x = not_na[, col_opt])))
     
     # Get a vector of just the unique 'bad' entries
-    bad_vec <- base::unique(bad_df[, col_opt])
+    bad_vec <- unique(bad_df[, col_opt])
     
     # If that vector is length 0 (i.e., no bad entries)...
-    if(base::length(bad_vec) == 0){
+    if(length(bad_vec) == 0){
       # ...print a message saying so
       message("For '", col_opt, "', no non-numeric values identified.")
       
