@@ -9,9 +9,9 @@ test_that("Errors work as desired", {
   mat <- matrix(data = c(1:2, 2:1), nrow = 2, ncol = 2)
   
   # More testing
-  expect_error(crop_tri(data = mat, drop_tri = NULL, drop_diag = FALSE))
-  expect_error(crop_tri(data = mat, drop_tri = c("upper", "lower"), drop_diag = FALSE))
-  expect_error(crop_tri(data = mat, drop_tri = "both", drop_diag = FALSE))
+  expect_error(supportR::crop_tri(data = mat, drop_tri = NULL, drop_diag = FALSE))
+  expect_error(supportR::crop_tri(data = mat, drop_tri = c("upper", "lower"), drop_diag = FALSE))
+  expect_error(supportR::crop_tri(data = mat, drop_tri = "both", drop_diag = FALSE))
 })
 
 # Warning testing
@@ -21,7 +21,7 @@ test_that("Warnings work as desired", {
   mat <- matrix(data = c(1:2, 2:1), nrow = 2, ncol = 2)
   
   # Malformed logical warning
-  expect_warning(crop_tri(data = mat, drop_tri = "upper", drop_diag = "true"))
+  expect_warning(supportR::crop_tri(data = mat, drop_tri = "upper", drop_diag = "true"))
 })
 
 # # Message testing
@@ -37,7 +37,7 @@ test_that("Outputs are as expected", {
   mat <- matrix(data = c(1:2, 2:1), nrow = 2, ncol = 2)
   
   # Crop to one triangle
-  cropped_mat <- crop_tri(data = mat, drop_tri = "upper", drop_diag = TRUE)
+  cropped_mat <- supportR::crop_tri(data = mat, drop_tri = "upper", drop_diag = TRUE)
   
   # Simple outputs testing
   expect_equal(class(mat), class(cropped_mat))
